@@ -1,4 +1,4 @@
-use crate::v1::CipherKind;
+use crate::kind::{CipherCategory, CipherKind};
 
 #[cfg(feature = "v1-aead-extra")]
 mod aes_ccm;
@@ -152,6 +152,11 @@ impl AeadCipher {
         self.cipher.kind()
     }
 
+    #[inline(always)]
+    pub fn category(&self) -> CipherCategory {
+        CipherCategory::Aead
+    }
+
     #[inline(always)]
     pub fn tag_len(&self) -> usize {
         self.cipher.kind().tag_len()
